@@ -4,7 +4,7 @@
 
     Lexers for automation scripting languages.
 
-    :copyright: Copyright 2006-2021 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2022 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -17,11 +17,12 @@ __all__ = ['AutohotkeyLexer', 'AutoItLexer']
 
 class AutohotkeyLexer(RegexLexer):
     """
-    For `autohotkey <http://www.autohotkey.com/>`_ source code.
+    For autohotkey source code.
 
     .. versionadded:: 1.4
     """
     name = 'autohotkey'
+    url = 'http://www.autohotkey.com/'
     aliases = ['autohotkey', 'ahk']
     filenames = ['*.ahk', '*.ahkl']
     mimetypes = ['text/x-autohotkey']
@@ -49,8 +50,8 @@ class AutohotkeyLexer(RegexLexer):
         ],
         'incomment': [
             (r'^\s*\*/', Comment.Multiline, '#pop'),
-            (r'[^*/]', Comment.Multiline),
-            (r'[*/]', Comment.Multiline)
+            (r'[^*]+', Comment.Multiline),
+            (r'\*', Comment.Multiline)
         ],
         'incontinuation': [
             (r'^\s*\)', Generic, '#pop'),
@@ -194,7 +195,7 @@ class AutohotkeyLexer(RegexLexer):
 
 class AutoItLexer(RegexLexer):
     """
-    For `AutoIt <http://www.autoitscript.com/site/autoit/>`_ files.
+    For AutoIt files.
 
     AutoIt is a freeware BASIC-like scripting language
     designed for automating the Windows GUI and general scripting
@@ -202,6 +203,7 @@ class AutoItLexer(RegexLexer):
     .. versionadded:: 1.6
     """
     name = 'AutoIt'
+    url = 'http://www.autoitscript.com/site/autoit/'
     aliases = ['autoit']
     filenames = ['*.au3']
     mimetypes = ['text/x-autoit']
